# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.models.repository_version_response import RepositoryVersionResponse  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException

class TestRepositoryVersionResponse(unittest.TestCase):
    """RepositoryVersionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RepositoryVersionResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_rpm.models.repository_version_response.RepositoryVersionResponse()  # noqa: E501
        if include_optional :
            return RepositoryVersionResponse(
                pulp_href = '0', 
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                number = 56, 
                base_version = '0', 
                content_summary = null
            )
        else :
            return RepositoryVersionResponse(
        )

    def testRepositoryVersionResponse(self):
        """Test RepositoryVersionResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.models.rpm_package_response import RpmPackageResponse  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException

class TestRpmPackageResponse(unittest.TestCase):
    """RpmPackageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RpmPackageResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_rpm.models.rpm_package_response.RpmPackageResponse()  # noqa: E501
        if include_optional :
            return RpmPackageResponse(
                pulp_href = '0', 
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                artifact = '0', 
                name = '0', 
                epoch = '0', 
                version = '0', 
                release = '0', 
                arch = '0', 
                pkg_id = '0', 
                checksum_type = '0', 
                summary = '0', 
                description = '0', 
                url = '0', 
                changelogs = None, 
                files = None, 
                requires = None, 
                provides = None, 
                conflicts = None, 
                obsoletes = None, 
                suggests = None, 
                enhances = None, 
                recommends = None, 
                sha256 = '0', 
                supplements = None, 
                location_base = '0', 
                location_href = '0', 
                rpm_buildhost = '0', 
                rpm_group = '0', 
                rpm_license = '0', 
                rpm_packager = '0', 
                rpm_sourcerpm = '0', 
                rpm_vendor = '0', 
                rpm_header_start = 56, 
                rpm_header_end = 56, 
                is_modular = True, 
                size_archive = 56, 
                size_installed = 56, 
                size_package = 56, 
                time_build = 56, 
                time_file = 56
            )
        else :
            return RpmPackageResponse(
        )

    def testRpmPackageResponse(self):
        """Test RpmPackageResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.models.inline_response2008 import InlineResponse2008  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException

class TestInlineResponse2008(unittest.TestCase):
    """InlineResponse2008 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse2008
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_rpm.models.inline_response2008.InlineResponse2008()  # noqa: E501
        if include_optional :
            return InlineResponse2008(
                count = 123, 
                next = '0', 
                previous = '0', 
                results = [
                    pulpcore.client.pulp_rpm.models.rpm/package_response.rpm.PackageResponse(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        artifact = '0', 
                        name = '0', 
                        epoch = '0', 
                        version = '0', 
                        release = '0', 
                        arch = '0', 
                        pkg_id = '0', 
                        checksum_type = '0', 
                        summary = '0', 
                        description = '0', 
                        url = '0', 
                        changelogs = pulpcore.client.pulp_rpm.models.changelogs.changelogs(), 
                        files = pulpcore.client.pulp_rpm.models.files.files(), 
                        requires = pulpcore.client.pulp_rpm.models.requires.requires(), 
                        provides = pulpcore.client.pulp_rpm.models.provides.provides(), 
                        conflicts = pulpcore.client.pulp_rpm.models.conflicts.conflicts(), 
                        obsoletes = pulpcore.client.pulp_rpm.models.obsoletes.obsoletes(), 
                        suggests = pulpcore.client.pulp_rpm.models.suggests.suggests(), 
                        enhances = pulpcore.client.pulp_rpm.models.enhances.enhances(), 
                        recommends = pulpcore.client.pulp_rpm.models.recommends.recommends(), 
                        sha256 = '0', 
                        supplements = pulpcore.client.pulp_rpm.models.supplements.supplements(), 
                        location_base = '0', 
                        location_href = '0', 
                        rpm_buildhost = '0', 
                        rpm_group = '0', 
                        rpm_license = '0', 
                        rpm_packager = '0', 
                        rpm_sourcerpm = '0', 
                        rpm_vendor = '0', 
                        rpm_header_start = 56, 
                        rpm_header_end = 56, 
                        is_modular = True, 
                        size_archive = 56, 
                        size_installed = 56, 
                        size_package = 56, 
                        time_build = 56, 
                        time_file = 56, )
                    ]
            )
        else :
            return InlineResponse2008(
        )

    def testInlineResponse2008(self):
        """Test InlineResponse2008"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class RpmRpmPublicationResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'repository_version': 'str',
        'repository': 'str',
        'metadata_checksum_type': 'MetadataChecksumTypeEnum',
        'package_checksum_type': 'PackageChecksumTypeEnum'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'repository_version': 'repository_version',
        'repository': 'repository',
        'metadata_checksum_type': 'metadata_checksum_type',
        'package_checksum_type': 'package_checksum_type'
    }

    def __init__(self, pulp_href=None, pulp_created=None, repository_version=None, repository=None, metadata_checksum_type=None, package_checksum_type=None, local_vars_configuration=None):  # noqa: E501
        """RpmRpmPublicationResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._repository_version = None
        self._repository = None
        self._metadata_checksum_type = None
        self._package_checksum_type = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        if repository_version is not None:
            self.repository_version = repository_version
        if repository is not None:
            self.repository = repository
        if metadata_checksum_type is not None:
            self.metadata_checksum_type = metadata_checksum_type
        if package_checksum_type is not None:
            self.package_checksum_type = package_checksum_type

    @property
    def pulp_href(self):
        """Gets the pulp_href of this RpmRpmPublicationResponse.  # noqa: E501


        :return: The pulp_href of this RpmRpmPublicationResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this RpmRpmPublicationResponse.


        :param pulp_href: The pulp_href of this RpmRpmPublicationResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this RpmRpmPublicationResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this RpmRpmPublicationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this RpmRpmPublicationResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this RpmRpmPublicationResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def repository_version(self):
        """Gets the repository_version of this RpmRpmPublicationResponse.  # noqa: E501


        :return: The repository_version of this RpmRpmPublicationResponse.  # noqa: E501
        :rtype: str
        """
        return self._repository_version

    @repository_version.setter
    def repository_version(self, repository_version):
        """Sets the repository_version of this RpmRpmPublicationResponse.


        :param repository_version: The repository_version of this RpmRpmPublicationResponse.  # noqa: E501
        :type: str
        """

        self._repository_version = repository_version

    @property
    def repository(self):
        """Gets the repository of this RpmRpmPublicationResponse.  # noqa: E501

        A URI of the repository to be published.  # noqa: E501

        :return: The repository of this RpmRpmPublicationResponse.  # noqa: E501
        :rtype: str
        """
        return self._repository

    @repository.setter
    def repository(self, repository):
        """Sets the repository of this RpmRpmPublicationResponse.

        A URI of the repository to be published.  # noqa: E501

        :param repository: The repository of this RpmRpmPublicationResponse.  # noqa: E501
        :type: str
        """

        self._repository = repository

    @property
    def metadata_checksum_type(self):
        """Gets the metadata_checksum_type of this RpmRpmPublicationResponse.  # noqa: E501

        The checksum type for metadata.  # noqa: E501

        :return: The metadata_checksum_type of this RpmRpmPublicationResponse.  # noqa: E501
        :rtype: MetadataChecksumTypeEnum
        """
        return self._metadata_checksum_type

    @metadata_checksum_type.setter
    def metadata_checksum_type(self, metadata_checksum_type):
        """Sets the metadata_checksum_type of this RpmRpmPublicationResponse.

        The checksum type for metadata.  # noqa: E501

        :param metadata_checksum_type: The metadata_checksum_type of this RpmRpmPublicationResponse.  # noqa: E501
        :type: MetadataChecksumTypeEnum
        """

        self._metadata_checksum_type = metadata_checksum_type

    @property
    def package_checksum_type(self):
        """Gets the package_checksum_type of this RpmRpmPublicationResponse.  # noqa: E501

        The checksum type for packages.  # noqa: E501

        :return: The package_checksum_type of this RpmRpmPublicationResponse.  # noqa: E501
        :rtype: PackageChecksumTypeEnum
        """
        return self._package_checksum_type

    @package_checksum_type.setter
    def package_checksum_type(self, package_checksum_type):
        """Sets the package_checksum_type of this RpmRpmPublicationResponse.

        The checksum type for packages.  # noqa: E501

        :param package_checksum_type: The package_checksum_type of this RpmRpmPublicationResponse.  # noqa: E501
        :type: PackageChecksumTypeEnum
        """

        self._package_checksum_type = package_checksum_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RpmRpmPublicationResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RpmRpmPublicationResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.models.inline_response20012 import InlineResponse20012  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException

class TestInlineResponse20012(unittest.TestCase):
    """InlineResponse20012 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse20012
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_rpm.models.inline_response20012.InlineResponse20012()  # noqa: E501
        if include_optional :
            return InlineResponse20012(
                count = 123, 
                next = '0', 
                previous = '0', 
                results = [
                    pulpcore.client.pulp_rpm.models.rpm/rpm_remote_response.rpm.RpmRemoteResponse(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '0', 
                        url = '0', 
                        ca_cert = '0', 
                        client_cert = '0', 
                        client_key = '0', 
                        tls_validation = True, 
                        proxy_url = '0', 
                        username = '0', 
                        password = '0', 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        download_concurrency = 1, 
                        policy = null, 
                        sles_auth_token = '0', )
                    ]
            )
        else :
            return InlineResponse20012(
        )

    def testInlineResponse20012(self):
        """Test InlineResponse20012"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class RpmRepoMetadataFileResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'artifact': 'str',
        'relative_path': 'str',
        'data_type': 'str',
        'checksum_type': 'str',
        'checksum': 'str',
        'sha256': 'str'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'artifact': 'artifact',
        'relative_path': 'relative_path',
        'data_type': 'data_type',
        'checksum_type': 'checksum_type',
        'checksum': 'checksum',
        'sha256': 'sha256'
    }

    def __init__(self, pulp_href=None, pulp_created=None, artifact=None, relative_path=None, data_type=None, checksum_type=None, checksum=None, sha256=None, local_vars_configuration=None):  # noqa: E501
        """RpmRepoMetadataFileResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._artifact = None
        self._relative_path = None
        self._data_type = None
        self._checksum_type = None
        self._checksum = None
        self._sha256 = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        if artifact is not None:
            self.artifact = artifact
        self.relative_path = relative_path
        self.data_type = data_type
        self.checksum_type = checksum_type
        self.checksum = checksum
        if sha256 is not None:
            self.sha256 = sha256

    @property
    def pulp_href(self):
        """Gets the pulp_href of this RpmRepoMetadataFileResponse.  # noqa: E501


        :return: The pulp_href of this RpmRepoMetadataFileResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this RpmRepoMetadataFileResponse.


        :param pulp_href: The pulp_href of this RpmRepoMetadataFileResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this RpmRepoMetadataFileResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this RpmRepoMetadataFileResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this RpmRepoMetadataFileResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this RpmRepoMetadataFileResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def artifact(self):
        """Gets the artifact of this RpmRepoMetadataFileResponse.  # noqa: E501

        Artifact file representing the physical content  # noqa: E501

        :return: The artifact of this RpmRepoMetadataFileResponse.  # noqa: E501
        :rtype: str
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this RpmRepoMetadataFileResponse.

        Artifact file representing the physical content  # noqa: E501

        :param artifact: The artifact of this RpmRepoMetadataFileResponse.  # noqa: E501
        :type: str
        """

        self._artifact = artifact

    @property
    def relative_path(self):
        """Gets the relative_path of this RpmRepoMetadataFileResponse.  # noqa: E501

        Relative path of the file.  # noqa: E501

        :return: The relative_path of this RpmRepoMetadataFileResponse.  # noqa: E501
        :rtype: str
        """
        return self._relative_path

    @relative_path.setter
    def relative_path(self, relative_path):
        """Sets the relative_path of this RpmRepoMetadataFileResponse.

        Relative path of the file.  # noqa: E501

        :param relative_path: The relative_path of this RpmRepoMetadataFileResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and relative_path is None:  # noqa: E501
            raise ValueError("Invalid value for `relative_path`, must not be `None`")  # noqa: E501

        self._relative_path = relative_path

    @property
    def data_type(self):
        """Gets the data_type of this RpmRepoMetadataFileResponse.  # noqa: E501

        Metadata type.  # noqa: E501

        :return: The data_type of this RpmRepoMetadataFileResponse.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this RpmRepoMetadataFileResponse.

        Metadata type.  # noqa: E501

        :param data_type: The data_type of this RpmRepoMetadataFileResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and data_type is None:  # noqa: E501
            raise ValueError("Invalid value for `data_type`, must not be `None`")  # noqa: E501

        self._data_type = data_type

    @property
    def checksum_type(self):
        """Gets the checksum_type of this RpmRepoMetadataFileResponse.  # noqa: E501

        Checksum type for the file.  # noqa: E501

        :return: The checksum_type of this RpmRepoMetadataFileResponse.  # noqa: E501
        :rtype: str
        """
        return self._checksum_type

    @checksum_type.setter
    def checksum_type(self, checksum_type):
        """Sets the checksum_type of this RpmRepoMetadataFileResponse.

        Checksum type for the file.  # noqa: E501

        :param checksum_type: The checksum_type of this RpmRepoMetadataFileResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and checksum_type is None:  # noqa: E501
            raise ValueError("Invalid value for `checksum_type`, must not be `None`")  # noqa: E501

        self._checksum_type = checksum_type

    @property
    def checksum(self):
        """Gets the checksum of this RpmRepoMetadataFileResponse.  # noqa: E501

        Checksum for the file.  # noqa: E501

        :return: The checksum of this RpmRepoMetadataFileResponse.  # noqa: E501
        :rtype: str
        """
        return self._checksum

    @checksum.setter
    def checksum(self, checksum):
        """Sets the checksum of this RpmRepoMetadataFileResponse.

        Checksum for the file.  # noqa: E501

        :param checksum: The checksum of this RpmRepoMetadataFileResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and checksum is None:  # noqa: E501
            raise ValueError("Invalid value for `checksum`, must not be `None`")  # noqa: E501

        self._checksum = checksum

    @property
    def sha256(self):
        """Gets the sha256 of this RpmRepoMetadataFileResponse.  # noqa: E501

        The SHA-256 checksum if available.  # noqa: E501

        :return: The sha256 of this RpmRepoMetadataFileResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this RpmRepoMetadataFileResponse.

        The SHA-256 checksum if available.  # noqa: E501

        :param sha256: The sha256 of this RpmRepoMetadataFileResponse.  # noqa: E501
        :type: str
        """

        self._sha256 = sha256

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RpmRepoMetadataFileResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RpmRepoMetadataFileResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.models.inline_response2001 import InlineResponse2001  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException

class TestInlineResponse2001(unittest.TestCase):
    """InlineResponse2001 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse2001
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_rpm.models.inline_response2001.InlineResponse2001()  # noqa: E501
        if include_optional :
            return InlineResponse2001(
                count = 123, 
                next = '0', 
                previous = '0', 
                results = [
                    pulpcore.client.pulp_rpm.models.rpm/distribution_tree_response.rpm.DistributionTreeResponse(
                        pulp_href = '0', 
                        header_version = '0', 
                        release_name = '0', 
                        release_short = '0', 
                        release_version = '0', 
                        release_is_layered = True, 
                        base_product_name = '0', 
                        base_product_short = '0', 
                        base_product_version = '0', 
                        arch = '0', 
                        build_timestamp = 1.337, 
                        instimage = '0', 
                        mainimage = '0', 
                        discnum = 56, 
                        totaldiscs = 56, 
                        addons = [
                            pulpcore.client.pulp_rpm.models.addon_response.AddonResponse(
                                addon_id = '0', 
                                uid = '0', 
                                name = '0', 
                                type = '0', 
                                packages = '0', )
                            ], 
                        checksums = [
                            pulpcore.client.pulp_rpm.models.checksum_response.ChecksumResponse(
                                path = '0', 
                                checksum = '0', )
                            ], 
                        images = [
                            pulpcore.client.pulp_rpm.models.image_response.ImageResponse(
                                name = '0', 
                                path = '0', 
                                platforms = '0', 
                                artifact = pulpcore.client.pulp_rpm.models.artifact_response.ArtifactResponse(
                                    pulp_href = '0', 
                                    pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    file = '0', 
                                    size = 56, 
                                    md5 = '0', 
                                    sha1 = '0', 
                                    sha224 = '0', 
                                    sha256 = '0', 
                                    sha384 = '0', 
                                    sha512 = '0', ), )
                            ], 
                        variants = [
                            pulpcore.client.pulp_rpm.models.variant_response.VariantResponse(
                                variant_id = '0', 
                                uid = '0', 
                                name = '0', 
                                type = '0', 
                                packages = '0', 
                                source_packages = '0', 
                                source_repository = '0', 
                                debug_packages = '0', 
                                debug_repository = '0', 
                                identity = '0', )
                            ], )
                    ]
            )
        else :
            return InlineResponse2001(
        )

    def testInlineResponse2001(self):
        """Test InlineResponse2001"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
